==> developer_support-0.0.1.tar.gz: README.md <==
Logger
Log model
// TaskEntity.dart
@JsonSerializable()
class TaskEntity {
TaskEntity({
this.sale,
this.title,
this.price,
this.rate,
this.image,
});

String? sale;
String? title;
String? price;
int? rate;
String? image;

factory TaskEntity.fromJson(dynamic json) => _$TaskEntityFromJson(json);
Map<String, dynamic> toJson() => _$TaskEntityToJson(this);
}

taskEntity.Log("taskEntity :..");
taskEntity.image.Log("image :..");
taskEntity.Log("taskEntity :..").image.Log("image :..");
`````

***Result***
I/flutter (24235): ⋙ taskEntity :.. {"sale":"Sale","title":"Cashmere Carpenter Beanie","price":"80.000","rate":5,"image":"https://graphicriver.img.customer.envatousercontent.com/files/251467394/DOTO-1255-Product%20Sale%20Sliders%20Design_Main%20Preview.jpg?auto=compress%2Cformat&q=80&fit=crop&crop=top&max-h=8000&max-w=590&s=d307e5c2ec56602c9332aeb7d1a35882"}
I/flutter (24235): ⋙ image :.. https://graphicriver.img.customer.envatousercontent.com/files/251467394/DOTO-1255-Product%20Sale%20Sliders%20Design_Main%20Preview.jpg?auto=compress%2Cformat&q=80&fit=crop&crop=top&max-h=8000&max-w=590&s=d307e5c2ec56602c9332aeb7d1a35882
#### Log inside widget
Container( margin: const EdgeInsets.only( left: 15, ), child: ClipRRect( borderRadius: BorderRadius.circular(10), child: Container( height: 80, width: 80, color: Colors.blue, child: CachedNetworkImage( imageUrl: taskEntity.Log("taskEntity :..").image.Log("image :..") ?? "" ), ), ), ),
***Result***
I/flutter (24235): ⋙ taskEntity :.. {"sale":"Sale","title":"Cashmere Carpenter Beanie","price":"80.000","rate":5,"image":"https://graphicriver.img.customer.envatousercontent.com/files/251467394/DOTO-1255-Product%20Sale%20Sliders%20Design_Main%20Preview.jpg?auto=compress%2Cformat&q=80&fit=crop&crop=top&max-h=8000&max-w=590&s=d307e5c2ec56602c9332aeb7d1a35882"}
I/flutter (24235): ⋙ image :.. https://graphicriver.img.customer.envatousercontent.com/files/251467394/DOTO-1255-Product%20Sale%20Sliders%20Design_Main%20Preview.jpg?auto=compress%2Cformat&q=80&fit=crop&crop=top&max-h=8000&max-w=590&s=d307e5c2ec56602c9332aeb7d1a35882
#### Log large string.
String largeString =.....; largeString.Log("tag name :..",true)
#### Logcat

![image](https://drive.google.com/uc?export=view&id=1RMvD2W2eGT59lc841mTeuEvriSBFAgzQ)

Filter with:
~~~ : lọc nhưng dòng dùng logger;
: lọc kết quả call api.
logger : hiện thị tất cả. ```

==> developer_support-0.0.2.tar.gz: README.md <==
Logger Log model // TaskEntity.dart @JsonSerializable()
class TaskEntity { TaskEntity({ this.sale, this.title, this.price, this.rate, this.image, });

String? sale; String? title; String? price; int? rate; String? image;

factory TaskEntity.fromJson(dynamic json) => _$TaskEntityFromJson(json); Map<String, dynamic>
toJson() => _$TaskEntityToJson(this); }

taskEntity.Log("taskEntity :.."); taskEntity.image.Log("image :.."); taskEntity.Log("taskEntity :
..").image.Log("image :..");

`````

***Result***
I/flutter (24235): ⋙ taskEntity :.. {"sale":"Sale","title":"Cashmere Carpenter Beanie","price":"80.000","rate":5,"image":"https://graphicriver.img.customer.envatousercontent.com/files/251467394/DOTO-1255-Product%20Sale%20Sliders%20Design_Main%20Preview.jpg?auto=compress%2Cformat&q=80&fit=crop&crop=top&max-h=8000&max-w=590&s=d307e5c2ec56602c9332aeb7d1a35882"}
I/flutter (24235): ⋙ image :.. https://graphicriver.img.customer.envatousercontent.com/files/251467394/DOTO-1255-Product%20Sale%20Sliders%20Design_Main%20Preview.jpg?auto=compress%2Cformat&q=80&fit=crop&crop=top&max-h=8000&max-w=590&s=d307e5c2ec56602c9332aeb7d1a35882
#### Log inside widget
Container( margin: const EdgeInsets.only( left: 15, ), child: ClipRRect( borderRadius: BorderRadius.circular(10), child: Container( height: 80, width: 80, color: Colors.blue, child: CachedNetworkImage( imageUrl: taskEntity.Log("taskEntity :..").image.Log("image :..") ?? "" ), ), ), ),
***Result***
I/flutter (24235): ⋙ taskEntity :.. {"sale":"Sale","title":"Cashmere Carpenter Beanie","price":"80.000","rate":5,"image":"https://graphicriver.img.customer.envatousercontent.com/files/251467394/DOTO-1255-Product%20Sale%20Sliders%20Design_Main%20Preview.jpg?auto=compress%2Cformat&q=80&fit=crop&crop=top&max-h=8000&max-w=590&s=d307e5c2ec56602c9332aeb7d1a35882"}
I/flutter (24235): ⋙ image :.. https://graphicriver.img.customer.envatousercontent.com/files/251467394/DOTO-1255-Product%20Sale%20Sliders%20Design_Main%20Preview.jpg?auto=compress%2Cformat&q=80&fit=crop&crop=top&max-h=8000&max-w=590&s=d307e5c2ec56602c9332aeb7d1a35882
#### Log large string.
String largeString =.....; largeString.Log("tag name :..",true)
#### Logcat

![image](https://drive.google.com/uc?export=view&id=1RMvD2W2eGT59lc841mTeuEvriSBFAgzQ)

Filter with:
~~~ : lọc nhưng dòng dùng logger;
: lọc kết quả call api.
logger : hiện thị tất cả. ```
